pub enum UploadError {
}Expand description
Errors that can occur during an upload.
Variants
InvalidOptions(String)
The upload options are invalid.
Io(Error)
An I/O error occurred while reading the data to upload.
RPC(RPCError)
A host RPC error occurred during the upload.
Encoder(Error)
The erasure encoder encountered an error.
NotEnoughShards(u8, u8)
Not enough shards were successfully uploaded.
OutOfRange(usize, usize)
The requested range is out of bounds.
Timeout(Elapsed)
A host RPC timed out.
QueueError(QueueError)
An error from the host queue.
SemaphoreError(AcquireError)
An internal semaphore error.
JoinError(JoinError)
An internal task join error.
ApiError(Error)
An error from the indexer API.
InvalidSlabId
The slab ID returned by the indexer does not match the expected value.
Cancelled
The upload was cancelled.